import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { firstValueFrom } from 'rxjs';
import { environment } from 'src/environments/environment';
import { UsersService } from './users.service';

export enum Visibility {
    Public,
    Unlisted,
    Private,
}
export interface Image {
    id: string;
    author: string;
    name: string;
    visibility: Visibility;
    created: number;
    file: string;
}
export interface CreateImageBody {
    name?: string;
    visibility?: Visibility;
}
export type Page = {} | { n: number; } | { n: number; i: number; };

@Injectable({
    providedIn: 'root'
})
export class ImagesService {
    private readonly url = environment.apiURL + '/images';

    public async get(id: string) {
        return await firstValueFrom(this.http.get<Image>(`${this.url}`, {
            ...this.users.httpOptions,
            params: { id }
        }));
    }
    public async feed(page: Page = {}) {
        return await firstValueFrom(this.http.get<Image[]>(`${this.url}/feed`,
            this.users.httpOptions({ params: page })
        ));
    }
    public async userFeed(username: string, page: Page = {}) {
        return await firstValueFrom(this.http.get<Image[]>(`${this.url}/feed/${username}`,
            this.users.httpOptions({ params: page })
        ));
    }

    public async upload(proto: CreateImageBody, file: File) {
        const data = new FormData();
        data.append('file', file, file.name);
        data.append('body', JSON.stringify(proto));
        return await firstValueFrom(this.http.post<string>(`${this.url}/upload`, data, this.users.httpOptions({})));
    }
    public async change(id: string, proto: CreateImageBody) {
        return await firstValueFrom(this.http.post<string>(`${this.url}/change?id=${id}`, proto, this.users.httpOptions({})));
    }

    public constructor(private http: HttpClient, private users: UsersService) {
    }
}
